@@ -13,37 +13,37 @@ set.seed(1234)
 
 #### clayton
 cop <- claytonCopula(2, dim=5)
-u <- rcopula(cop, 10)
+u <- rCopula(10, cop)
 
-derCdfWrtParams(cop, u)
-derCdfWrtArgs(cop, u)
+dCdtheta(cop, u)
+dCdu(cop, u)
 derPdfWrtParams(cop, u)
 derPdfWrtArgs(cop, u)
 
 #### gumbel
 cop <- gumbelCopula(2, dim=5)
-u <- rcopula(cop, 10)
+u <- rCopula(10, cop)
 
-derCdfWrtParams(cop, u)
-derCdfWrtArgs(cop, u)
+dCdtheta(cop, u)
+dCdu(cop, u)
 derPdfWrtParams(cop, u)
 derPdfWrtArgs(cop, u)
 
 
 #### frank
 cop <- frankCopula(2, dim=5)
-u <- rcopula(cop, 10)
+u <- rCopula(10, cop)
 
-derCdfWrtParams(cop, u)
-derCdfWrtArgs(cop, u)
+dCdtheta(cop, u)
+dCdu(cop, u)
 derPdfWrtParams(cop, u)
 derPdfWrtArgs(cop, u)
 
 #### plackett
 cop <- plackettCopula(2) # dim = 2 only
-u <- rcopula(cop, 10)
+u <- rCopula(10, cop)
 
-derCdfWrtParams(cop, u)
-derCdfWrtArgs(cop, u)
+dCdtheta(cop, u)
+dCdu(cop, u)
 derPdfWrtParams(cop, u)
 derPdfWrtArgs(cop, u)
